@@ -29,7 +29,6 @@ from .qpsolvers import (
     __version__,
     available_solvers,
     cvxopt_solve_qp,
-    cvxpy_solve_qp,
     dense_solvers,
     ecos_solve_qp,
     gurobi_solve_qp,
@@ -52,7 +51,6 @@ __all__ = [
     "__version__",
     "available_solvers",
     "cvxopt_solve_qp",
-    "cvxpy_solve_qp",
     "dense_solvers",
     "ecos_solve_qp",
     "gurobi_solve_qp",
