@@ -25,7 +25,6 @@ from .solve_qp import solve_qp, solve_safer_qp
 from .solvers import (
     available_solvers,
     cvxopt_solve_qp,
-    cvxpy_solve_qp,
     dense_solvers,
     ecos_solve_qp,
     gurobi_solve_qp,
@@ -41,13 +40,12 @@ from .solvers import (
 )
 from .utils import print_matrix_vector
 
-__version__ = "2.5.0"
+__version__ = "2.6.0"
 
 __all__ = [
     "__version__",
     "available_solvers",
     "cvxopt_solve_qp",
-    "cvxpy_solve_qp",
     "dense_solvers",
     "ecos_solve_qp",
     "gurobi_solve_qp",
