@@ -19,14 +19,13 @@
 # along with qpsolvers. If not, see <http://www.gnu.org/licenses/>.
 
 """
-Helper function to solve least squares.
+Solve linear least squares.
 """
 
 from typing import Optional, Union
 
 import numpy as np
 import scipy.sparse as spa
-from numpy import dot, ndarray
 
 from .solve_qp import solve_qp
 
@@ -46,7 +45,7 @@ def solve_ls(
     sym_proj: bool = False,
     verbose: bool = False,
     **kwargs,
-) -> Optional[ndarray]:
+) -> Optional[np.ndarray]:
     """
     Solve a constrained weighted linear Least Squares problem defined as:
 
@@ -110,9 +109,11 @@ def solve_ls(
     """
     if sym_proj:
         R = 0.5 * (R + R.transpose())
-    WR: Union[np.ndarray, spa.csc_matrix] = R if W is None else dot(W, R)
-    P = dot(R.transpose(), WR)
-    q = -dot(s.transpose(), WR)
+    WR: Union[np.ndarray, spa.csc_matrix] = R if W is None else W @ R
+    P = R.T @ WR
+    q = -(s.T @ WR)
+    if not isinstance(P, np.ndarray):
+        P = P.tocsc()
     return solve_qp(
         P,
         q,
