@@ -64,38 +64,6 @@ except ImportError:
     pass
 
 
-# CVXPY
-# =====
-
-cvxpy_solve_qp: Optional[
-    Callable[
-        [
-            ndarray,
-            ndarray,
-            Optional[ndarray],
-            Optional[ndarray],
-            Optional[ndarray],
-            Optional[ndarray],
-            Optional[ndarray],
-            Optional[ndarray],
-            Optional[ndarray],
-            Optional[str],
-            bool,
-        ],
-        Optional[ndarray],
-    ]
-] = None
-
-try:
-    from .cvxpy_ import cvxpy_solve_qp
-
-    solve_function["cvxpy"] = cvxpy_solve_qp
-    available_solvers.append("cvxpy")
-    sparse_solvers.append("cvxpy")
-except ImportError:
-    pass
-
-
 # ECOS
 # ====
 
@@ -143,7 +111,6 @@ gurobi_solve_qp: Optional[
             Optional[ndarray],
             Optional[ndarray],
             bool,
-            Optional[float],
         ],
         Optional[ndarray],
     ]
@@ -175,7 +142,6 @@ highs_solve_qp: Optional[
             Optional[ndarray],
             Optional[ndarray],
             bool,
-            Optional[float],
         ],
         Optional[ndarray],
     ]
@@ -303,6 +269,7 @@ qpoases_solve_qp: Optional[
             Optional[ndarray],
             bool,
             int,
+            Optional[float],
         ],
         Optional[ndarray],
     ]
@@ -421,7 +388,6 @@ if not available_solvers:
 __all__ = [
     "available_solvers",
     "cvxopt_solve_qp",
-    "cvxpy_solve_qp",
     "dense_solvers",
     "gurobi_solve_qp",
     "mosek_solve_qp",
