@@ -18,14 +18,23 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with qpsolvers. If not, see <http://www.gnu.org/licenses/>.
 
-"""Solver interface for CVXOPT."""
+"""
+Solver interface for `CVXOPT <https://cvxopt.org/>`__.
 
-from typing import Any, Dict, Optional, Union
+CVXOPT is a free software package for convex optimization in Python. Its main
+purpose is to make the development of software for convex optimization
+applications straightforward by building on Python’s extensive standard library
+and on the strengths of Python as a high-level programming language. If you are
+using CVXOPT in some academic work, consider citing the corresponding report
+[Vandenberghe2010]_.
+"""
+
+from typing import Dict, Optional, Union
 
 import cvxopt
+import numpy as np
+import scipy.sparse as spa
 from cvxopt.solvers import qp
-from numpy import array, ndarray
-from scipy.sparse import csc_matrix
 
 from .conversions import linear_from_box_inequalities
 
@@ -33,7 +42,7 @@ cvxopt.solvers.options["show_progress"] = False  # disable verbose output
 
 
 def to_cvxopt(
-    M: Union[ndarray, csc_matrix]
+    M: Union[np.ndarray, spa.csc_matrix]
 ) -> Union[cvxopt.matrix, cvxopt.spmatrix]:
     """
     Convert matrix to CVXOPT format.
@@ -48,7 +57,7 @@ def to_cvxopt(
     :
         Matrix in CVXOPT format.
     """
-    if isinstance(M, ndarray):
+    if isinstance(M, np.ndarray):
         return cvxopt.matrix(M)
     coo = M.tocoo()
     return cvxopt.spmatrix(
@@ -57,23 +66,19 @@ def to_cvxopt(
 
 
 def cvxopt_solve_qp(
-    P: Union[ndarray, csc_matrix],
-    q: ndarray,
-    G: Optional[Union[ndarray, csc_matrix]] = None,
-    h: Optional[ndarray] = None,
-    A: Optional[Union[ndarray, csc_matrix]] = None,
-    b: Optional[ndarray] = None,
-    lb: Optional[ndarray] = None,
-    ub: Optional[ndarray] = None,
-    solver: str = None,
-    initvals: Optional[ndarray] = None,
+    P: Union[np.ndarray, spa.csc_matrix],
+    q: np.ndarray,
+    G: Optional[Union[np.ndarray, spa.csc_matrix]] = None,
+    h: Optional[np.ndarray] = None,
+    A: Optional[Union[np.ndarray, spa.csc_matrix]] = None,
+    b: Optional[np.ndarray] = None,
+    lb: Optional[np.ndarray] = None,
+    ub: Optional[np.ndarray] = None,
+    solver: Optional[str] = None,
+    initvals: Optional[np.ndarray] = None,
     verbose: bool = False,
-    maxiters: Optional[int] = None,
-    abstol: Optional[float] = None,
-    reltol: Optional[float] = None,
-    feastol: Optional[float] = None,
-    refinement: Optional[int] = None,
-) -> Optional[ndarray]:
+    **kwargs,
+) -> Optional[np.ndarray]:
     """
     Solve a Quadratic Program defined as:
 
@@ -121,22 +126,6 @@ def cvxopt_solve_qp(
         Warm-start guess vector.
     verbose :
         Set to `True` to print out extra information.
-    maxiters :
-        Maximum number of iterations.
-    abstol :
-        Absolute tolerance on the duality gap. See [Vandenberghe2010]_ or
-        *e.g.* [tolprimer]_ for a primer on the duality gap.
-    reltol :
-        Relative tolerance on the duality gap. See [Vandenberghe2010]_ or
-        *e.g.* [tolprimer]_ for a primer on the duality gap.
-    feastol :
-        Tolerance for feasibility conditions, that is, for the primal residual
-        equality and inequality constraints. See *e.g.* [tolprimer]_ for a
-        primer on primal-dual residuals.
-    refinement :
-        Number of iterative refinement steps when solving KKT equations
-        (default: ``0`` if the problem has no second-order cone or matrix
-        inequality constraints; ``1`` otherwise).
 
     Returns
     -------
@@ -167,44 +156,53 @@ def cvxopt_solve_qp(
     CVXOPT only considers the lower entries of `P`, therefore it will use a
     different cost than the one intended if a non-symmetric matrix is provided.
 
-    See the `Algorithm Parameters
+    Keyword arguments are forwarded as options to CVXOPT. For instance, we can
+    call ``cvxopt_solve_qp(P, q, G, h, u, abstol=1e-4, reltol=1e-4)``. CVXOPT
+    options include the following:
+
+    .. list-table::
+       :widths: 30 70
+       :header-rows: 1
+
+       * - Name
+         - Description
+       * - ``abstol``
+         - Absolute tolerance on the duality gap.
+       * - ``reltol``
+         - Relative tolerance on the duality gap.
+       * - ``feastol``
+         - Tolerance on feasibility conditions, that is, on the primal
+           residual.
+       * - ``refinement``
+         - Number of iterative refinement steps when solving KKT equations
+
+    Check out `Algorithm Parameters
     <https://cvxopt.org/userguide/coneprog.html#algorithm-parameters>`_ section
-    of the solver documentation for more details and default values of the
-    solver parameters.
+    of the solver documentation for details and default values of all solver
+    parameters. See also [tolerances]_ for a primer on the duality gap, primal
+    and dual residuals.
     """
     if lb is not None or ub is not None:
         G, h = linear_from_box_inequalities(G, h, lb, ub)
 
-    # Update solver options if applicable
-    options: Dict[str, Any] = {"show_progress": verbose}
-    if maxiters:
-        options["maxiters"] = maxiters
-    if abstol:
-        options["abstol"] = abstol
-    if reltol:
-        options["reltol"] = reltol
-    if feastol:
-        options["feastol"] = feastol
-    if refinement:
-        options["refinement"] = refinement
-
     args = [to_cvxopt(P), to_cvxopt(q)]
-    kwargs = {"G": None, "h": None, "A": None, "b": None}
+    constraints = {"G": None, "h": None, "A": None, "b": None}
     if G is not None and h is not None:
-        kwargs["G"] = to_cvxopt(G)
-        kwargs["h"] = to_cvxopt(h)
+        constraints["G"] = to_cvxopt(G)
+        constraints["h"] = to_cvxopt(h)
     if A is not None and b is not None:
-        kwargs["A"] = to_cvxopt(A)
-        kwargs["b"] = to_cvxopt(b)
+        constraints["A"] = to_cvxopt(A)
+        constraints["b"] = to_cvxopt(b)
     initvals_dict: Optional[Dict[str, cvxopt.matrix]] = None
     if initvals is not None:
         initvals_dict = {"x": to_cvxopt(initvals)}
 
+    kwargs["show_progress"] = verbose
     original_options = cvxopt.solvers.options
-    cvxopt.solvers.options = options
-    sol = qp(*args, solver=solver, initvals=initvals_dict, **kwargs)
+    cvxopt.solvers.options = kwargs
+    solution = qp(*args, solver=solver, initvals=initvals_dict, **constraints)
     cvxopt.solvers.options = original_options
 
-    if "optimal" not in sol["status"]:
+    if "optimal" not in solution["status"]:
         return None
-    return array(sol["x"]).reshape((q.shape[0],))
+    return np.array(solution["x"]).reshape((q.shape[0],))
