@@ -18,10 +18,20 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with qpsolvers. If not, see <http://www.gnu.org/licenses/>.
 
-"""Solver interface for ECOS"""
+"""
+Solver interface for `ECOS <https://github.com/embotech/ecos>`__.
 
+ECOS is an interior-point solver for convex second-order cone programs (SOCPs).
+designed specifically for embedded applications. ECOS is written in low
+footprint, single-threaded, library-free ANSI-C and so runs on most embedded
+platforms. For small problems, ECOS is faster than most existing SOCP solvers;
+it is still competitive for medium-sized problems up to tens of thousands of
+variables. If you are using ECOS in some academic work, consider citing the
+corresponding paper [Domahidi2013]_.
+"""
+
+import warnings
 from typing import Optional, Union
-from warnings import warn
 
 import numpy as np
 from ecos import solve
@@ -121,11 +131,11 @@ def ecos_solve_qp(
 
     See the `ECOS Python wrapper documentation
     <https://github.com/embotech/ecos-python#calling-ecos-from-python>`_ for
-    more details. You can also check out [tolprimer]_ for a primer on
+    more details. You can also check out [tolerances]_ for a primer on
     primal-dual residuals or the duality gap.
     """
     if initvals is not None:
-        warn("note that warm-start values ignored by this wrapper")
+        warnings.warn("warm-start values are ignored by this wrapper")
     if lb is not None or ub is not None:
         G, h = linear_from_box_inequalities(G, h, lb, ub)
     kwargs.update(
@@ -141,6 +151,6 @@ def ecos_solve_qp(
         solution = solve(c_socp, G_socp, h_socp, dims, **kwargs)
     flag = solution["info"]["exitFlag"]
     if flag != 0:
-        warn(f"ECOS returned exit flag {flag} ({__exit_flag_meaning__[flag]})")
+        warnings.warn(f"ECOS returned exit flag {flag} ({__exit_flag_meaning__[flag]})")
         return None
     return solution["x"][:-1]
