@@ -19,30 +19,38 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with qpsolvers. If not, see <http://www.gnu.org/licenses/>.
 
-"""Solver interface for Gurobi."""
+"""
+Solver interface for `Gurobi <https://www.gurobi.com/>`__.
 
-from typing import Optional
-from warnings import warn
+The Gurobi Optimizer suite ships several solvers for mathematical programming,
+including problems that have linear constraints, bound constraints, integrality
+constraints, cone constraints, or quadratic constraints. It targets modern CPU
+architectures and multi-core processors,
+
+See the :ref:`installation page <gurobi-install>` for additional instructions
+on installing this solver.
+"""
+
+from typing import Optional, Union
+import warnings
 
 import numpy as np
+import scipy.sparse as spa
 from gurobipy import GRB, Model
-from numpy import array
-
-from .conversions import linear_from_box_inequalities
 
 
 def gurobi_solve_qp(
-    P: np.ndarray,
+    P: Union[np.ndarray, spa.csc_matrix],
     q: np.ndarray,
-    G: Optional[np.ndarray] = None,
+    G: Optional[Union[np.ndarray, spa.csc_matrix]] = None,
     h: Optional[np.ndarray] = None,
-    A: Optional[np.ndarray] = None,
+    A: Optional[Union[np.ndarray, spa.csc_matrix]] = None,
     b: Optional[np.ndarray] = None,
     lb: Optional[np.ndarray] = None,
     ub: Optional[np.ndarray] = None,
     initvals: Optional[np.ndarray] = None,
     verbose: bool = False,
-    time_limit: Optional[float] = None,
+    **kwargs,
 ) -> Optional[np.ndarray]:
     """
     Solve a Quadratic Program defined as:
@@ -82,8 +90,6 @@ def gurobi_solve_qp(
         Warm-start guess vector (not used).
     verbose :
         Set to `True` to print out extra information.
-    time_limit :
-        Set a run time limit in seconds.
 
     Returns
     -------
@@ -92,31 +98,59 @@ def gurobi_solve_qp(
 
     Notes
     -----
-        Check out the `Gurobi documentation
-        <https://www.gurobi.com/documentation/>`_ for more information on the
-        solver.
+    Keyword arguments are forwarded to Gurobi as parameters. For instance, we
+    can call ``gurobi_solve_qp(P, q, G, h, u, FeasibilityTol=1e-8,
+    OptimalityTol=1e-8)``. Gurobi settings include the following:
+
+    .. list-table::
+       :widths: 30 70
+       :header-rows: 1
+
+       * - Name
+         - Description
+       * - ``FeasibilityTol``
+         - Primal feasibility tolerance.
+       * - ``OptimalityTol``
+         - Dual feasibility tolerance.
+       * - ``PSDTol``
+         - Positive semi-definite tolerance.
+       * - ``TimeLimit``
+         - Run time limit in seconds, 0 to disable.
+
+    Check out the `Parameter Descriptions
+    <https://www.gurobi.com/documentation/9.5/refman/parameter_descriptions.html>`_
+    documentation for all available Gurobi parameters.
+
+    Lower values for primal or dual tolerances yield more precise solutions at
+    the cost of computation time. See *e.g.* [tolerances]_ for a primer of
+    solver tolerances.
     """
     if initvals is not None:
-        warn("Gurobi: warm-start values given but they will be ignored")
-    if lb is not None or ub is not None:
-        G, h = linear_from_box_inequalities(G, h, lb, ub)
+        warnings.warn("warm-start values are ignored by this wrapper")
+
     model = Model()
     if not verbose:
-        model.setParam("OutputFlag", 0)
-    if time_limit:
-        model.setParam("TimeLimit", time_limit)
+        model.setParam(GRB.Param.OutputFlag, 0)
+    for param, value in kwargs.items():
+        model.setParam(param, value)
+
     num_vars = P.shape[0]
+    identity = spa.eye(num_vars)
     x = model.addMVar(
         num_vars, lb=-GRB.INFINITY, ub=GRB.INFINITY, vtype=GRB.CONTINUOUS
     )
-    if A is not None:  # include equality constraints
-        model.addMConstr(A, x, GRB.EQUAL, b)
-    if G is not None:  # include inequality constraints
+    if G is not None:
         model.addMConstr(G, x, GRB.LESS_EQUAL, h)
+    if A is not None:
+        model.addMConstr(A, x, GRB.EQUAL, b)
+    if lb is not None:
+        model.addMConstr(identity, x, GRB.GREATER_EQUAL, lb)
+    if ub is not None:
+        model.addMConstr(identity, x, GRB.LESS_EQUAL, ub)
     objective = 0.5 * (x @ P @ x) + q @ x
     model.setObjective(objective, sense=GRB.MINIMIZE)
     model.optimize()
     status = model.status
     if status not in (GRB.OPTIMAL, GRB.SUBOPTIMAL):
         return None
-    return array(x.X)
+    return np.array(x.X)
