@@ -18,10 +18,15 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with qpsolvers. If not, see <http://www.gnu.org/licenses/>.
 
-"""Solver interface for quadprog"""
+"""
+Solver interface for `quadprog <https://github.com/quadprog/quadprog>`__.
+
+quadprog is a C implementation of the Goldfarb-Idnani dual algorithm
+[Goldfarb1983]_. It works best on well-conditioned dense problems.
+"""
 
 from typing import Optional
-from warnings import warn
+import warnings
 
 import numpy as np
 from numpy import hstack, vstack
@@ -39,7 +44,7 @@ def quadprog_solve_qp(
     b: Optional[np.ndarray] = None,
     lb: Optional[np.ndarray] = None,
     ub: Optional[np.ndarray] = None,
-    initvals: np.ndarray = None,
+    initvals: Optional[np.ndarray] = None,
     verbose: bool = False,
     **kwargs,
 ) -> Optional[np.ndarray]:
@@ -100,7 +105,7 @@ def quadprog_solve_qp(
     See the solver documentation for details.
     """
     if initvals is not None and verbose:
-        warn("note that warm-start values ignored by quadprog")
+        warnings.warn("warm-start values are ignored by quadprog")
     if lb is not None or ub is not None:
         G, h = linear_from_box_inequalities(G, h, lb, ub)
     qp_G = P
@@ -129,5 +134,5 @@ def quadprog_solve_qp(
             raise ValueError("matrix P is not positive definite") from e
         if "no solution" in error:
             return None
-        warn(f"quadprog raised a ValueError: {e}")
+        warnings.warn(f"quadprog raised a ValueError: {e}")
         return None
