@@ -18,10 +18,17 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with qpsolvers. If not, see <http://www.gnu.org/licenses/>.
 
-"""Solver interface for SCS"""
+"""
+Solver interface for `SCS <https://www.cvxgrp.org/scs/>`__.
+
+SCS (Splitting Conic Solver) is a numerical optimization package for solving
+large-scale convex quadratic cone problems, which is a general class of
+problems that includes quadratic programming. If you use SCS in some academic
+work, consider citing the corresponding paper [ODonoghue2021]_.
+"""
 
 from typing import Any, Dict, Optional, Union
-from warnings import warn
+import warnings
 
 import numpy as np
 import scipy.sparse as spa
@@ -147,7 +154,7 @@ def scs_solve_qp(
             & lb \\leq x \\leq ub
         \\end{array}\\end{split}
 
-    using `SCS <https://github.com/cvxgrp/scs>`_.
+    using `SCS <https://github.com/cvxgrp/scs>`__.
 
     Parameters
     ----------
@@ -253,10 +260,8 @@ def scs_solve_qp(
     solution = solve(data, cone, **kwargs)
     status_val = solution["info"]["status_val"]
     if status_val != 1:
-        warn(
+        warnings.warn(
             f"SCS returned {status_val}: {__status_val_meaning__[status_val]}"
         )
-        if status_val != 2:
-            # solution is not inaccurate, so the optimization failed
-            return None
+        return None
     return solution["x"]
