@@ -25,22 +25,14 @@ Tests for the `solve_lp` function.
 import unittest
 import warnings
 
-from numpy import array, dot
+import numpy as np
+import scipy.sparse as spa
 from numpy.linalg import norm
 
-from qpsolvers import available_solvers, solve_ls
+from qpsolvers import available_solvers, solve_ls, sparse_solvers
 from qpsolvers.exceptions import NoSolverSelected, SolverNotFound
 
-
-def solve_ls_with_test_params(*args, **kwargs):
-    """
-    Call ``solve_lp`` with additional solver parameters
-    """
-    params = {}
-    if kwargs["solver"] == "proxqp":
-        params["eps_abs"] = 1e-9
-    kwargs.update(params)
-    return solve_ls(*args, **kwargs)
+from .problems import get_sparse_least_squares
 
 
 class TestSolveLS(unittest.TestCase):
@@ -55,12 +47,15 @@ class TestSolveLS(unittest.TestCase):
         """
         warnings.simplefilter("ignore", category=DeprecationWarning)
         warnings.simplefilter("ignore", category=UserWarning)
-        self.R = array([[1.0, 2.0, 0.0], [2.0, 3.0, 4.0], [0.0, 4.0, 1.0]])
-        self.s = array([3.0, 2.0, 3.0])
-        self.G = array([[1.0, 2.0, 1.0], [2.0, 0.0, 1.0], [-1.0, 2.0, -1.0]])
-        self.h = array([3.0, 2.0, -2.0]).reshape((3,))
-        self.A = array([1.0, 1.0, 1.0])
-        self.b = array([1.0])
+        self.R = np.array([[1.0, 2.0, 0.0], [2.0, 3.0, 4.0], [0.0, 4.0, 1.0]])
+        self.s = np.array([3.0, 2.0, 3.0])
+        self.G = np.array(
+            [[1.0, 2.0, 1.0], [2.0, 0.0, 1.0], [-1.0, 2.0, -1.0]]
+        )
+        self.h = np.array([3.0, 2.0, -2.0]).reshape((3,))
+        self.A = np.array([1.0, 1.0, 1.0])
+        self.b = np.array([1.0])
+        self.known_solution = np.array([2.0 / 3, -1.0 / 3, 2.0 / 3])
 
     def get_problem(self):
         """
@@ -101,29 +96,34 @@ class TestSolveLS(unittest.TestCase):
 
         def test(self):
             R, s, G, h, A, b = self.get_problem()
-            x = solve_ls_with_test_params(R, s, G, h, A, b, solver=solver)
-            x_sp = solve_ls_with_test_params(
-                R, s, G, h, A, b, solver=solver, sym_proj=True
-            )
+            x = solve_ls(R, s, G, h, A, b, solver=solver)
+            x_sp = solve_ls(R, s, G, h, A, b, solver=solver, sym_proj=True)
             self.assertIsNotNone(x)
             self.assertIsNotNone(x_sp)
-            known_solution = array([2.0 / 3, -1.0 / 3, 2.0 / 3])
             sol_tolerance = (
                 5e-3
                 if solver == "osqp"
+                else 2e-5
+                if solver == "proxqp"
                 else 1e-5
                 if solver == "ecos"
                 else 1e-6
             )
             eq_tolerance = 1e-9
             ineq_tolerance = (
-                1e-3 if solver == "osqp" else 2e-7 if solver == "scs" else 1e-9
+                1e-3
+                if solver == "osqp"
+                else 1e-5
+                if solver == "proxqp"
+                else 2e-7
+                if solver == "scs"
+                else 1e-9
             )
-            self.assertLess(norm(x - known_solution), sol_tolerance)
-            self.assertLess(norm(x_sp - known_solution), sol_tolerance)
-            self.assertLess(max(dot(G, x) - h), ineq_tolerance)
-            self.assertLess(max(dot(A, x) - b), eq_tolerance)
-            self.assertLess(min(dot(A, x) - b), eq_tolerance)
+            self.assertLess(norm(x - self.known_solution), sol_tolerance)
+            self.assertLess(norm(x_sp - self.known_solution), sol_tolerance)
+            self.assertLess(max(G.dot(x) - h), ineq_tolerance)
+            self.assertLess(max(A.dot(x) - b), eq_tolerance)
+            self.assertLess(min(A.dot(x) - b), eq_tolerance)
 
         return test
 
@@ -133,7 +133,7 @@ class TestSolveLS(unittest.TestCase):
         """
         R, s, G, h, A, b = self.get_problem()
         with self.assertRaises(NoSolverSelected):
-            solve_ls_with_test_params(R, s, G, h, A, b, solver=None)
+            solve_ls(R, s, G, h, A, b, solver=None)
 
     def test_solver_not_found(self):
         """
@@ -141,7 +141,92 @@ class TestSolveLS(unittest.TestCase):
         """
         R, s, G, h, A, b = self.get_problem()
         with self.assertRaises(SolverNotFound):
-            solve_ls_with_test_params(R, s, G, h, A, b, solver="ideal")
+            solve_ls(R, s, G, h, A, b, solver="ideal")
+
+    @staticmethod
+    def get_test_mixed_sparse_args(solver: str):
+        """
+        Get test function for mixed sparse problems with a given solver.
+
+        Parameters
+        ----------
+        solver :
+            Name of the solver to test.
+
+        Returns
+        -------
+        :
+            Test function for that solver.
+        """
+
+        def test(self):
+            _, s, G, h, A, b = self.get_problem()
+            n = len(s)
+
+            R_csc = spa.eye(n, format="csc")
+            x_csc = solve_ls(R_csc, s, G, h, A, b, solver=solver)
+            self.assertIsNotNone(x_csc)
+
+            R_dia = spa.eye(n)
+            x_dia = solve_ls(R_dia, s, G, h, A, b, solver=solver)
+            self.assertIsNotNone(x_dia)
+
+            x_np_dia = solve_ls(
+                R_dia, s, G, h, A, b, W=np.eye(n), solver=solver
+            )
+            self.assertIsNotNone(x_np_dia)
+
+            sol_tolerance = 1e-8
+            self.assertLess(norm(x_csc - x_dia), sol_tolerance)
+            self.assertLess(norm(x_csc - x_np_dia), sol_tolerance)
+
+        return test
+
+    @staticmethod
+    def get_test_medium_sparse_problem(solver: str):
+        """
+        Get test function for a large sparse problem with a given solver.
+
+        Parameters
+        ----------
+        solver :
+            Name of the solver to test.
+
+        Returns
+        -------
+        :
+            Test function for that solver.
+        """
+
+        def test(self):
+            R, s, G, h, A, b, lb, ub = get_sparse_least_squares(n=1500)
+            x = solve_ls(R, s, G, h, A, b, solver=solver)
+            self.assertIsNotNone(x)
+
+        return test
+
+    @staticmethod
+    def get_test_large_sparse_problem(solver: str):
+        """
+        Get test function for a large sparse problem with a given solver.
+
+        Parameters
+        ----------
+        solver :
+            Name of the solver to test.
+
+        Returns
+        -------
+        :
+            Test function for that solver.
+        """
+
+        def test(self):
+            R, s, G, h, A, b, lb, ub = get_sparse_least_squares(n=15_000)
+            x = solve_ls(R, s, G, h, A, b, solver=solver)
+            self.assertIsNotNone(x)
+
+        return test
 
 
 # Generate test fixtures for each solver
@@ -149,3 +234,24 @@ for solver in available_solvers:
     setattr(
         TestSolveLS, "test_{}".format(solver), TestSolveLS.get_test(solver)
     )
+for solver in sparse_solvers:
+    setattr(
+        TestSolveLS,
+        "test_mixed_sparse_args_{}".format(solver),
+        TestSolveLS.get_test_mixed_sparse_args(solver),
+    )
+    if solver != "gurobi":
+        # Gurobi: model too large for size-limited license
+        setattr(
+            TestSolveLS,
+            "test_medium_sparse_problem_{}".format(solver),
+            TestSolveLS.get_test_medium_sparse_problem(solver),
+        )
+    if solver not in ["gurobi", "scs"]:
+        # Gurobi: model too large for size-limited license
+        # SCS: issue reported in https://github.com/cvxgrp/scs/issues/234
+        setattr(
+            TestSolveLS,
+            "test_large_sparse_problem_{}".format(solver),
+            TestSolveLS.get_test_large_sparse_problem(solver),
+        )
