@@ -45,21 +45,10 @@ from qpsolvers.exceptions import NoSolverSelected, SolverNotFound
 behavior_on_unbounded = {
     "raise_value_error": ["cvxopt", "ecos", "quadprog", "scs"],
     "return_crazy_solution": ["qpoases"],
-    "return_none": ["cvxpy", "osqp"],
+    "return_none": ["osqp"],
 }
 
 
-def solve_qp_with_test_params(*args, **kwargs):
-    """
-    Call ``solve_qp`` with additional solver parameters
-    """
-    params = {}
-    if kwargs["solver"] == "proxqp":
-        params["eps_abs"] = 1e-9
-    kwargs.update(params)
-    return solve_qp(*args, **kwargs)
-
-
 class TestSolveQP(unittest.TestCase):
 
     """
@@ -138,7 +127,7 @@ class TestSolveQP(unittest.TestCase):
         """
         P, q, G, h, A, b = self.get_dense_problem()
         with self.assertRaises(NoSolverSelected):
-            solve_qp_with_test_params(P, q, G, h, A, b, solver=None)
+            solve_qp(P, q, G, h, A, b, solver=None)
 
     def test_solver_not_found(self):
         """
@@ -146,7 +135,7 @@ class TestSolveQP(unittest.TestCase):
         """
         P, q, G, h, A, b = self.get_dense_problem()
         with self.assertRaises(SolverNotFound):
-            solve_qp_with_test_params(P, q, G, h, A, b, solver="ideal")
+            solve_qp(P, q, G, h, A, b, solver="ideal")
 
     @staticmethod
     def get_test(solver):
@@ -166,10 +155,8 @@ class TestSolveQP(unittest.TestCase):
 
         def test(self):
             P, q, G, h, A, b = self.get_dense_problem()
-            x = solve_qp_with_test_params(P, q, G, h, A, b, solver=solver)
-            x_sp = solve_qp_with_test_params(
-                P, q, G, h, A, b, solver=solver, sym_proj=True
-            )
+            x = solve_qp(P, q, G, h, A, b, solver=solver)
+            x_sp = solve_qp(P, q, G, h, A, b, solver=solver, sym_proj=True)
             self.assertIsNotNone(x)
             self.assertIsNotNone(x_sp)
             known_solution = array([0.30769231, -0.69230769, 1.38461538])
@@ -180,10 +167,18 @@ class TestSolveQP(unittest.TestCase):
                 if solver == "scs"
                 else 1e-4
                 if solver == "ecos"
+                else 5e-6
+                if solver == "proxqp"
                 else 1e-8
             )
             eq_tolerance = 1e-10
-            ineq_tolerance = 2e-4 if solver == "scs" else 1e-10
+            ineq_tolerance = (
+                2e-4
+                if solver == "scs"
+                else 5e-6
+                if solver == "proxqp"
+                else 1e-10
+            )
             self.assertLess(norm(x - known_solution), sol_tolerance)
             self.assertLess(norm(x_sp - known_solution), sol_tolerance)
             self.assertLess(max(dot(G, x) - h), ineq_tolerance)
@@ -215,102 +210,51 @@ class TestSolveQP(unittest.TestCase):
 
         def test(self):
             P, q, G, h, _, _ = self.get_dense_problem()
-            h0 = array([h[0]])
             A = array([[1.0, 0.0, 0.0], [0.0, 0.4, 0.5]])
             b = array([-0.5, -1.2])
-            b0 = array([b[0]])
             lb = array([-0.5, -2, -0.8])
             ub = array([+1.0, +1.0, +1.0])
 
+            ineq_variants = ((None, None), (G, h), (G[0], array([h[0]])))
+            eq_variants = ((None, None), (A, b), (A[0], array([b[0]])))
+            box_variants = ((None, None), (lb, None), (None, ub), (lb, ub))
             cases = [
-                {"P": P, "q": q},
-                {"P": P, "q": q, "G": G, "h": h},
-                {"P": P, "q": q, "G": G[0], "h": h0},
-                {"P": P, "q": q, "A": A, "b": b},
-                {"P": P, "q": q, "A": A[0], "b": b0},
-                {"P": P, "q": q, "lb": lb, "ub": None},
-                {"P": P, "q": q, "lb": None, "ub": ub},
-                {"P": P, "q": q, "lb": lb, "ub": ub},
-                {"P": P, "q": q, "G": G, "h": h, "A": A, "b": b},
-                {"P": P, "q": q, "G": G[0], "h": h0, "A": A, "b": b},
-                {"P": P, "q": q, "G": G, "h": h, "A": A[0], "b": b0},
-                {"P": P, "q": q, "G": G[0], "h": h0, "A": A[0], "b": b0},
                 {
                     "P": P,
                     "q": q,
-                    "G": G,
-                    "h": h,
-                    "A": A,
-                    "b": b,
-                    "lb": lb,
-                    "ub": None,
-                },
-                {
-                    "P": P,
-                    "q": q,
-                    "G": G,
-                    "h": h,
-                    "A": A,
-                    "b": b,
-                    "lb": None,
-                    "ub": ub,
-                },
-                {
-                    "P": P,
-                    "q": q,
-                    "G": G,
-                    "h": h,
-                    "A": A,
-                    "b": b,
-                    "lb": lb,
-                    "ub": ub,
-                },
-                {
-                    "P": P,
-                    "q": q,
-                    "G": G,
-                    "h": h,
-                    "lb": lb,
-                    "ub": None,
-                },
-                {
-                    "P": P,
-                    "q": q,
-                    "G": G,
-                    "h": h,
-                    "lb": None,
-                    "ub": ub,
-                },
-                {
-                    "P": P,
-                    "q": q,
-                    "G": G,
-                    "h": h,
-                    "lb": lb,
-                    "ub": ub,
-                },
+                    "G": G_case,
+                    "h": h_case,
+                    "A": A_case,
+                    "b": b_case,
+                    "lb": lb_case,
+                    "ub": ub_case,
+                }
+                for (G_case, h_case) in ineq_variants
+                for (A_case, b_case) in eq_variants
+                for (lb_case, ub_case) in box_variants
             ]
 
             for (i, test_case) in enumerate(cases):
-                if "G" not in test_case and solver == "qpswift":
+                no_inequality = "G" not in test_case or test_case["G"] is None
+                if no_inequality and solver == "qpswift":
                     # QPs without inequality constraints not handled by qpSWIFT
                     continue
                 test_comp = {
                     k: v.shape if v is not None else "None"
                     for k, v in test_case.items()
                 }
-                quadprog_solution = solve_qp_with_test_params(
-                    solver="quadprog", **test_case
-                )
+                quadprog_solution = solve_qp(solver="quadprog", **test_case)
                 self.assertIsNotNone(
                     quadprog_solution,
                     f"Baseline failed on parameters: {test_comp}",
                 )
-                solver_solution = solve_qp_with_test_params(
-                    solver=solver, **test_case
-                )
+                solver_solution = solve_qp(solver=solver, **test_case)
                 sol_tolerance = (
-                    2e-3
+                    2e-2
+                    if solver == "proxqp"
+                    else 1e-3
+                    if solver == "scs"
+                    else 2e-3
                     if solver == "osqp"
                     else 5e-4
                     if solver == "ecos"
@@ -344,13 +288,13 @@ class TestSolveQP(unittest.TestCase):
             P, q, G, h, A, b = self.get_dense_problem()
             lb = array([-1.0, -2.0, -0.5])
             ub = array([1.0, -0.2, 1.0])
-            x = solve_qp_with_test_params(
-                P, q, G, h, A, b, lb, ub, solver=solver
-            )
+            x = solve_qp(P, q, G, h, A, b, lb, ub, solver=solver)
             self.assertIsNotNone(x)
             known_solution = array([0.41463415, -0.41463415, 1.0])
             sol_tolerance = (
-                5e-3
+                2e-3
+                if solver == "proxqp"
+                else 5e-3
                 if solver == "osqp"
                 else 5e-5
                 if solver == "scs"
@@ -358,8 +302,8 @@ class TestSolveQP(unittest.TestCase):
                 if solver == "ecos"
                 else 1e-8
             )
-            eq_tolerance = 1e-10
-            ineq_tolerance = 1e-10
+            eq_tolerance = 1e-5 if solver == "proxqp" else 1e-10
+            ineq_tolerance = 1e-5 if solver == "proxqp" else 1e-10
             self.assertLess(norm(x - known_solution), sol_tolerance)
             self.assertLess(max(dot(G, x) - h), ineq_tolerance)
             self.assertLess(max(dot(A, x) - b), eq_tolerance)
@@ -386,7 +330,7 @@ class TestSolveQP(unittest.TestCase):
 
         def test(self):
             P, q, G, h, A, b = self.get_dense_problem()
-            x = solve_qp_with_test_params(P, q, solver=solver)
+            x = solve_qp(P, q, solver=solver)
             self.assertIsNotNone(x)
             known_solution = array([-0.64705882, -1.17647059, -1.82352941])
             sol_tolerance = (
@@ -419,7 +363,7 @@ class TestSolveQP(unittest.TestCase):
 
         def test(self):
             P, q, G, h, A, b = self.get_dense_problem()
-            x = solve_qp_with_test_params(P, q, G, h, solver=solver)
+            x = solve_qp(P, q, G, h, solver=solver)
             self.assertIsNotNone(x)
             known_solution = array([-0.49025721, -1.57755261, -0.66484801])
             sol_tolerance = (
@@ -432,6 +376,8 @@ class TestSolveQP(unittest.TestCase):
             ineq_tolerance = (
                 2e-6
                 if solver == "osqp"
+                else 1e-6
+                if solver == "proxqp"
                 else 1e-7
                 if solver == "scs"
                 else 1e-10
@@ -460,7 +406,7 @@ class TestSolveQP(unittest.TestCase):
 
         def test(self):
             P, q, G, h, A, b = self.get_dense_problem()
-            x = solve_qp_with_test_params(P, q, A=A, b=b, solver=solver)
+            x = solve_qp(P, q, A=A, b=b, solver=solver)
             self.assertIsNotNone(x)
             known_solution = array([0.28026906, -1.55156951, 2.27130045])
             sol_tolerance = (
@@ -470,6 +416,8 @@ class TestSolveQP(unittest.TestCase):
                 if solver in ["ecos", "scs"]
                 else 1e-6
                 if solver == "highs"
+                else 1e-7
+                if solver == "proxqp"
                 else 1e-8
             )
             eq_tolerance = 1e-9
@@ -499,7 +447,7 @@ class TestSolveQP(unittest.TestCase):
         def test(self):
             P, q, G, h, A, b = self.get_dense_problem()
             G, h = G[1], h[1].reshape((1,))
-            x = solve_qp_with_test_params(P, q, G, h, A, b, solver=solver)
+            x = solve_qp(P, q, G, h, A, b, solver=solver)
             self.assertIsNotNone(x)
             known_solution = array([0.30769231, -0.69230769, 1.38461538])
             sol_tolerance = (
@@ -507,6 +455,8 @@ class TestSolveQP(unittest.TestCase):
                 if solver == "osqp"
                 else 1e-5
                 if solver == "scs"
+                else 5e-6
+                if solver == "proxqp"
                 else 1e-6
                 if solver in ["cvxopt", "ecos"]
                 else 5e-8
@@ -515,7 +465,9 @@ class TestSolveQP(unittest.TestCase):
             )
             eq_tolerance = 5e-10 if solver in ["osqp", "scs"] else 1e-10
             ineq_tolerance = (
-                1e-7
+                5e-6
+                if solver == "proxqp"
+                else 1e-7
                 if solver == "scs"
                 else 2e-8
                 if solver == "qpswift"
@@ -560,7 +512,13 @@ class TestSolveQP(unittest.TestCase):
                 if solver in ["ecos", "scs"]
                 else 1e-6
             )
-            ineq_tolerance = 1e-7 if solver == "scs" else 1e-10
+            ineq_tolerance = (
+                1e-7
+                if solver == "scs"
+                else 1e-6
+                if solver == "proxqp"
+                else 1e-10
+            )
             self.assertLess(norm(x - known_solution), sol_tolerance)
             self.assertLess(max(dot(G, x) - h), ineq_tolerance)
 
@@ -585,7 +543,7 @@ class TestSolveQP(unittest.TestCase):
 
         def test(self):
             P, q, G, h = self.get_sparse_problem()
-            x = solve_qp_with_test_params(P, q, G, h, solver=solver)
+            x = solve_qp(P, q, G, h, solver=solver)
             self.assertIsNotNone(x)
             known_solution = array([2.0] * 149 + [3.0])
             sol_tolerance = (
@@ -597,12 +555,20 @@ class TestSolveQP(unittest.TestCase):
                 if solver == "osqp"
                 else 1e-4
                 if solver == "scs"
+                else 2e-5
+                if solver == "proxqp"
                 else 1e-6
                 if solver == "highs"
                 else 1e-7
             )
             ineq_tolerance = (
-                1e-4 if solver == "scs" else 5e-7 if solver == "osqp" else 1e-7
+                1e-4
+                if solver == "scs"
+                else 2e-5
+                if solver == "proxqp"
+                else 5e-7
+                if solver == "osqp"
+                else 1e-7
             )
             self.assertLess(norm(x - known_solution), sol_tolerance)
             self.assertLess(max(G * x - h), ineq_tolerance)
@@ -630,16 +596,16 @@ class TestSolveQP(unittest.TestCase):
             P, q, G, h = self.get_sparse_problem()
             lb = +2.2 * ones(q.shape)
             ub = +2.4 * ones(q.shape)
-            x = solve_qp_with_test_params(
-                P, q, G, h, lb=lb, ub=ub, solver=solver
-            )
+            x = solve_qp(P, q, G, h, lb=lb, ub=ub, solver=solver)
             self.assertIsNotNone(x)
             known_solution = array([2.2] * 149 + [2.4])
             sol_tolerance = (
                 1e-3
                 if solver == "gurobi"
-                else 5e-5
+                else 1e-3
                 if solver == "osqp"
+                else 5e-6
+                if solver == "proxqp"
                 else 1e-7
                 if solver in ["cvxopt", "scs"]
                 else 1e-8
@@ -675,9 +641,7 @@ class TestSolveQP(unittest.TestCase):
                 # Skipping this test for CVXOPT for now
                 # See https://github.com/cvxopt/cvxopt/issues/229
                 return
-            x = solve_qp_with_test_params(
-                P, q, G, h, lb=lb, ub=ub, solver=solver
-            )
+            x = solve_qp(P, q, G, h, lb=lb, ub=ub, solver=solver)
             self.assertIsNone(x)
 
         return test
@@ -702,7 +666,7 @@ class TestSolveQP(unittest.TestCase):
             P, q, G, h, A, b = self.get_dense_problem()
             known_solution = array([0.30769231, -0.69230769, 1.38461538])
             initvals = known_solution + 0.1 * random.random(3)
-            x = solve_qp_with_test_params(
+            x = solve_qp(
                 P,
                 q,
                 G,
@@ -721,10 +685,18 @@ class TestSolveQP(unittest.TestCase):
                 if solver == "osqp"
                 else 1e-4
                 if solver == "ecos"
+                else 5e-6
+                if solver == "proxqp"
                 else 1e-8
             )
             eq_tolerance = 5e-5 if solver == "osqp" else 1e-10
-            ineq_tolerance = 2e-4 if solver in ["osqp", "scs"] else 1e-10
+            ineq_tolerance = (
+                2e-4
+                if solver in ["osqp", "scs"]
+                else 5e-6
+                if solver == "proxqp"
+                else 1e-10
+            )
             self.assertLess(norm(x - known_solution), sol_tolerance)
             self.assertLess(max(dot(G, x) - h), ineq_tolerance)
             self.assertLess(max(dot(A, x) - b), eq_tolerance)
@@ -762,7 +734,7 @@ class TestSolveQP(unittest.TestCase):
             q = array([-1.0, -2, 0, 3e-4])
             # q is in the nullspace of P, so the problem is unbounded below
             with self.assertRaises(ValueError):
-                solve_qp_with_test_params(P, q, solver=solver)
+                solve_qp(P, q, solver=solver)
 
         return test
 
